@@ -33,7 +33,7 @@ class ConfigReader(object):
   "Read a configuration file"
 
   escapes = [
-      ('\n', '&10;'), (':', '&58;'), ('#', '&35;'), (',', '&44;')
+      ('\n', '&10;'), (':', '&58;'), ('#', '&35;')
       ]
 
   def __init__(self, filename):
@@ -76,10 +76,7 @@ class ConfigReader(object):
     if not ':' in line:
       Trace.error('Invalid configuration parameter ' + line)
       return
-    pieces = line.split(':')
-    if len(pieces) > 2:
-      Trace.error('Too many colons in ' + line)
-      return
+    pieces = line.split(':', 1)
     key = self.serializer.unescape(pieces[0])
     value = self.serializer.deserialize(pieces[1])
     object = self.objects[self.section]
@@ -215,7 +212,7 @@ class ConfigSerializer(object):
       result += self.escape(value) + ','
     if len(object) > 0:
       result = result[:-1]
-    return result
+    return '[' + result + ']'
 
   def pyserialize(self, object):
     "Convert an object to a Python definition"
@@ -237,10 +234,10 @@ class ConfigSerializer(object):
 
   def deserialize(self, string):
     "Parse a string into an object (string or list)"
-    if not ',' in string:
+    if not string.startswith('[') or not string.endswith(']') or not ',' in string:
       return self.unescape(string)
     result = []
-    contents = string.split(',')
+    contents = string[1:-1].split(',')
     for piece in contents:
       result.append(self.unescape(piece))
     return result
