@@ -25,6 +25,7 @@
 import sys
 from gen.container import *
 from util.trace import Trace
+from util.clone import *
 from conf.config import *
 from math.formula import *
 from math.command import *
@@ -53,7 +54,7 @@ class FormulaCell(FormulaCommand):
   def parsebit(self, pos):
     formula = WholeFormula()
     if not formula.detect(pos):
-      Trace.error('Unexpected end of array cell at ' + pos.remaining())
+      Trace.error('Unexpected end of array cell at ' + pos.identifier())
       pos.skip(pos.current())
       return
     formula.parsebit(pos)
@@ -79,8 +80,7 @@ class FormulaRow(FormulaCommand):
       cell.parsebit(pos)
       self.add(cell)
       index += 1
-      if pos.checkfor(FormulaRow.cellseparator):
-        pos.skip(FormulaRow.cellseparator)
+      pos.checkskip(FormulaRow.cellseparator)
     return
     for cell in self.iteratecells(pos):
       cell.parsebit(pos)
@@ -200,7 +200,7 @@ class BeginCommand(CommandBit):
     "Find the command bit corresponding to the \\begin{piece}"
     for bit in BeginCommand.innerbits:
       if bit.piece == piece or bit.piece + '*' == piece:
-        newbit = bit.clone()
+        newbit = Cloner.clone(bit)
         return newbit
     bit = Environment()
     bit.piece = piece
